MutableStateList<T> class
- Implemented types
-
- Iterable<
T>
- Iterable<
- Available extensions
Constructors
- MutableStateList(ViewModel _viewModel)
Properties
- first → T
-
The first element.
no setteroverride
- firstOrNull → T?
-
Available on Iterable<
The first element of this iterator, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
indexed
→ Iterable<
(int, T)> -
Available on Iterable<
Pairs of elements of the indices and elements of this iterable.T> , provided by the IterableExtensions extensionno setter - isEmpty → bool
-
Whether this collection has no elements.
no setteroverride
- isNotEmpty → bool
-
Whether this collection has at least one element.
no setteroverride
-
iterator
→ Iterator<
T> -
A new
Iteratorthat allows iterating the elements of thisIterable.no setteroverride - last → T
-
The last element.
no setteroverride
- lastOrNull → T?
-
Available on Iterable<
The last element of this iterable, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - length → int
-
The number of elements in this Iterable.
no setteroverride
-
nonNulls
→ Iterable<
T> -
Available on Iterable<
The non-T?> , provided by the NullableIterableExtensions extensionnullelements of this iterable.no setter -
reversed
→ Iterable<
T> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- single → T
-
Checks that this iterable has only one element, and returns that element.
no setteroverride
- singleOrNull → T?
-
Available on Iterable<
The single element of this iterator, orT> , provided by the IterableExtensions extensionnull.no setter -
toJSIterable
→ JSIterable<
T> -
Available on Iterable<
A JSIterable wrapper that proxies to the Dart iterable API.T> , provided by the IterableToJSIterable extensionno setter -
wait
→ Future<
List< T> > -
Available on Iterable<
Waits for futures in parallel.Future< , provided by the FutureIterable extensionT> >no setter
Methods
-
add(
T value) → void -
addAll(
Iterable< T> iterable) → void -
any(
bool test(T element)) → bool -
Checks whether any element of this iterable satisfies
test.override -
asNameMap(
) → Map< String, T> -
Available on Iterable<
Creates a map from the names of enum values to the values.T> , provided by the EnumByName extension -
byName(
String name) → T -
Available on Iterable<
Finds the enum value in this list with nameT> , provided by the EnumByName extensionname. -
cast<
R> () → Iterable< R> -
A view of this iterable as an iterable of
Rinstances.override -
clear(
) → void -
contains(
Object? element) → bool -
Whether the collection contains an element equal to
element.override -
elementAt(
int index) → T -
Returns the
indexth element.override -
elementAtOrNull(
int index) → T? -
Available on Iterable<
The element at positionT> , provided by the IterableExtensions extensionindexof this iterable, ornull. -
every(
bool test(T element)) → bool -
Checks whether every element of this iterable satisfies
test.override -
expand<
E> (Iterable< E> toElements(T element)) → Iterable<E> -
Expands each element of this Iterable into zero or more elements.
override
-
firstWhere(
bool test(T element), {T orElse()?}) → T -
The first element that satisfies the given predicate
test.override -
fold<
E> (E initialValue, E combine(E previousValue, T element)) → E -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
override
-
followedBy(
Iterable< T> other) → Iterable<T> -
Creates the lazy concatenation of this iterable and
other.override -
forEach(
void action(T element)) → void -
Invokes
actionon each element of this iterable in iteration order.override -
indexOf(
T value) → int -
insert(
int index, T value) → void -
insertAll(
int index, Iterable< T> value) → void -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
override
-
lastWhere(
bool test(T element), {T orElse()?}) → T -
The last element that satisfies the given predicate
test.override -
map<
E> (E toElement(T e)) → Iterable< E> -
The current elements of this iterable modified by
toElement.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reduce(
T combine(T value, T element)) → T -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
override
-
remove(
T value) → void -
removeAt(
int index) → void -
removeWhere(
bool test(T)) → void -
replaceAll(
Iterable< T> iterable) → void -
singleWhere(
bool test(T element), {T orElse()?}) → T -
The single element that satisfies
test.override -
skip(
int count) → Iterable< T> -
Creates an Iterable that provides all but the first
countelements.override -
skipWhile(
bool test(T value)) → Iterable< T> -
Creates an
Iterablethat skips leading elements whiletestis satisfied.override -
take(
int count) → Iterable< T> -
Creates a lazy iterable of the
countfirst elements of this iterable.override -
takeWhile(
bool test(T value)) → Iterable< T> -
Creates a lazy iterable of the leading elements satisfying
test.override -
toList(
{bool growable = true}) → List< T> -
Creates a List containing the elements of this Iterable.
override
-
toSet(
) → Set< T> -
Creates a Set containing the same elements as this iterable.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
where(
bool test(T element)) → Iterable< T> -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.override -
whereType<
R> () → Iterable< R> -
Creates a new lazy Iterable with all elements that have type
T.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → T -
operator []=(
int index, T value) → void